<?php

namespace Drupal\sibs_api\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Url;
use Drupal\Component\Utility\UrlHelper;

/**
 * Class for Sibs Form.
 */
class SibsForm extends ControllerBase {

  /**
   * {@inheritdoc}
   */
  public function getForm($id) {
    $config = \Drupal::config('sibs_api.settings');
    $tempstore = \Drupal::service('tempstore.private')->get('sibs_api');

    $formConfig = $tempstore->get($id);
    if (!$formConfig["redirectUrl"]) {
      $formConfig["redirectUrl"] = $config->get('spg_return_url');
    }

    // Convert redirectUrl to absolute URL.
    if (!UrlHelper::isValid($formConfig["redirectUrl"], TRUE)) {
      $formConfig["redirectUrl"] = Url::fromUserInput(
          $formConfig["redirectUrl"],
          ['absolute' => TRUE]
        )->toString();
    }

    $formConfig["customerData"] = NULL;
    $formConfig["language"] = "pt";
    $formContext = $formConfig['formContext'];

    $formStyle = [
      "layout" => (!empty($config->get('spg_formStyle.layout'))) ? $config->get('spg_formStyle.layout') : 'default',
      "theme" => (!empty($config->get('spg_formStyle.theme'))) ? $config->get('spg_formStyle.theme') : 'default',
      "color" => [
        "primary" => $config->get('spg_formStyle.color.primary'),
        "secondary" => $config->get('spg_formStyle.color.secondary'),
        "border" => $config->get('spg_formStyle.color.border'),
        "surface" => $config->get('spg_formStyle.color.surface'),
        "header" => [
          "text" => (!empty($config->get('spg_formStyle.color.header.text'))) ? $config->get('spg_formStyle.color.header.text') : '#5C5C5C',
          "background" => (!empty($config->get('spg_formStyle.color.header.background'))) ? $config->get('spg_formStyle.color.header.background') : '#fff',
        ],
        "body" => [
          "text" => (!empty($config->get('spg_formStyle.color.body.text'))) ? $config->get('spg_formStyle.color.body.text') : '#5C5C5C',
          "background" => (!empty($config->get('spg_formStyle.color.body.background'))) ? $config->get('spg_formStyle.color.body.background') : '#fff',
        ],
      ],
      "font" => $config->get('spg_formStyle.font'),
    ];

    return [
      '#type' => 'inline_template',
      '#template' => '<form class="paymentSPG" spg-context="{{formContext}}" spg-config="{{formConfig}}" spg-style="{{formStyle}}"><form>',
      '#context' => [
        'formContext' => $formContext,
        'formConfig' => json_encode($formConfig),
        'formStyle' => json_encode($formStyle),
      ],
      '#cache' => [
        'max-age' => 0,
      ],
    ];
  }

}
